@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.2.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -47,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.2"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -65,10 +66,10 @@
 
 
 /* First part of user prologue.  */
-#line 1 "cfg_parse.y" /* yacc.c:338  */
+#line 1 "cfg_parse.y" /* yacc.c:337  */
 
 /*
-** oidentd_cfg_parse.y - oidentd configuration parser.
+** cfg_parse.y - oidentd configuration parser.
 ** Copyright (c) 2001-2006 Ryan McCabe <ryan@numb.org>
 ** Copyright (c) 2018-2019 Janik Rabe  <oidentd@janikrabe.com>
 **
@@ -129,7 +130,7 @@ list_t *pref_list;
 u_int16_t default_caps;
 
 
-#line 133 "cfg_parse.c" /* yacc.c:338  */
+#line 134 "cfg_parse.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -202,12 +203,12 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 65 "cfg_parse.y" /* yacc.c:353  */
+#line 65 "cfg_parse.y" /* yacc.c:352  */
 
 	int value;
 	char *string;
 
-#line 211 "cfg_parse.c" /* yacc.c:353  */
+#line 212 "cfg_parse.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -466,16 +467,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  78
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   270
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
   ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -515,8 +516,8 @@ static const yytype_uint16 yyrline[] =
        0,    86,    86,    89,    93,    95,    95,   110,   112,   116,
      116,   128,   128,   161,   163,   167,   167,   176,   181,   185,
      188,   191,   195,   197,   199,   201,   205,   235,   263,   293,
-     321,   323,   327,   335,   343,   373,   378,   380,   382,   391,
-     402,   404,   408,   415,   425,   454,   464,   466
+     321,   323,   327,   336,   351,   381,   386,   388,   390,   399,
+     410,   412,   416,   424,   435,   464,   474,   476
 };
 #endif
 
@@ -675,22 +676,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -805,7 +806,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
     }
@@ -909,7 +910,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1005,10 +1009,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1032,9 +1036,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1160,23 +1165,31 @@ yyparse (void)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
   *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
       YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1195,10 +1208,7 @@ yyparse (void)
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1214,12 +1224,11 @@ yyparse (void)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
@@ -1230,6 +1239,7 @@ yyparse (void)
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1238,11 +1248,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1315,7 +1325,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1336,7 +1346,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 95 "cfg_parse.y" /* yacc.c:1645  */
+#line 95 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (parser_mode != PARSE_USER) {
 			o_log(LOG_CRIT,
@@ -1347,19 +1357,19 @@ yyreduce:
 		cur_cap = xcalloc(1, sizeof(struct user_cap));
 		cur_cap->caps = default_caps;
 	}
-#line 1351 "cfg_parse.c" /* yacc.c:1645  */
+#line 1361 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 104 "cfg_parse.y" /* yacc.c:1645  */
+#line 104 "cfg_parse.y" /* yacc.c:1652  */
     {
 		list_prepend(&pref_list, cur_cap);
 	}
-#line 1359 "cfg_parse.c" /* yacc.c:1645  */
+#line 1369 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 116 "cfg_parse.y" /* yacc.c:1645  */
+#line 116 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (parser_mode != PARSE_SYSTEM)
 			YYABORT;
@@ -1369,11 +1379,11 @@ yyreduce:
 
 		user_db_set_default(cur_user);
 	}
-#line 1373 "cfg_parse.c" /* yacc.c:1645  */
+#line 1383 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 128 "cfg_parse.y" /* yacc.c:1645  */
+#line 128 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (parser_mode != PARSE_SYSTEM) {
 			free((yyvsp[0].string));
@@ -1401,45 +1411,45 @@ yyreduce:
 
 		free((yyvsp[0].string));
 	}
-#line 1405 "cfg_parse.c" /* yacc.c:1645  */
+#line 1415 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 155 "cfg_parse.y" /* yacc.c:1645  */
+#line 155 "cfg_parse.y" /* yacc.c:1652  */
     {
 		user_db_add(cur_user);
 	}
-#line 1413 "cfg_parse.c" /* yacc.c:1645  */
+#line 1423 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 167 "cfg_parse.y" /* yacc.c:1645  */
+#line 167 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap = xcalloc(1, sizeof(struct user_cap));
 		cur_cap->caps = default_caps;
 	}
-#line 1422 "cfg_parse.c" /* yacc.c:1645  */
+#line 1432 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 170 "cfg_parse.y" /* yacc.c:1645  */
+#line 170 "cfg_parse.y" /* yacc.c:1652  */
     {
 		list_prepend(&cur_user->cap_list, cur_cap);
 	}
-#line 1430 "cfg_parse.c" /* yacc.c:1645  */
+#line 1440 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 176 "cfg_parse.y" /* yacc.c:1645  */
+#line 176 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (cur_user == default_user)
 			default_caps = cur_cap->caps;
 	}
-#line 1439 "cfg_parse.c" /* yacc.c:1645  */
+#line 1449 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 205 "cfg_parse.y" /* yacc.c:1645  */
+#line 205 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (cur_cap->dest) {
 			if (parser_mode == PARSE_SYSTEM) {
@@ -1467,11 +1477,11 @@ yyreduce:
 
 		free((yyvsp[0].string));
 	}
-#line 1471 "cfg_parse.c" /* yacc.c:1645  */
+#line 1481 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 235 "cfg_parse.y" /* yacc.c:1645  */
+#line 235 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (cur_cap->fport) {
 			if (parser_mode == PARSE_SYSTEM) {
@@ -1488,7 +1498,7 @@ yyreduce:
 
 		if (extract_port_range((yyvsp[0].string), cur_cap->fport) == -1) {
 			if (parser_mode == PARSE_SYSTEM)
-				o_log(LOG_CRIT, "[line %u] Bad port: \"%s\"", current_line, (yyvsp[0].string));
+				o_log(LOG_CRIT, "[line %u] Bad port or port range: \"%s\"", current_line, (yyvsp[0].string));
 
 			free((yyvsp[0].string));
 			free_cap_entries(cur_cap);
@@ -1497,11 +1507,11 @@ yyreduce:
 
 		free((yyvsp[0].string));
 	}
-#line 1501 "cfg_parse.c" /* yacc.c:1645  */
+#line 1511 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 263 "cfg_parse.y" /* yacc.c:1645  */
+#line 263 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (cur_cap->src) {
 			if (parser_mode == PARSE_SYSTEM) {
@@ -1529,11 +1539,11 @@ yyreduce:
 
 		free((yyvsp[0].string));
 	}
-#line 1533 "cfg_parse.c" /* yacc.c:1645  */
+#line 1543 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 293 "cfg_parse.y" /* yacc.c:1645  */
+#line 293 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if (cur_cap->lport) {
 			if (parser_mode == PARSE_SYSTEM) {
@@ -1550,7 +1560,7 @@ yyreduce:
 
 		if (extract_port_range((yyvsp[0].string), cur_cap->lport) == -1) {
 			if (parser_mode == PARSE_SYSTEM)
-				o_log(LOG_CRIT, "[line %u] Bad port: \"%s\"", current_line, (yyvsp[0].string));
+				o_log(LOG_CRIT, "[line %u] Bad port or port range: \"%s\"", current_line, (yyvsp[0].string));
 
 			free((yyvsp[0].string));
 			free_cap_entries(cur_cap);
@@ -1559,33 +1569,41 @@ yyreduce:
 
 		free((yyvsp[0].string));
 	}
-#line 1563 "cfg_parse.c" /* yacc.c:1645  */
+#line 1573 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 32:
-#line 327 "cfg_parse.y" /* yacc.c:1645  */
+#line 327 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap->caps = CAP_REPLY;
 		cur_cap->action = ACTION_FORCE;
+		cur_cap->data.replies.num = 1;
 		cur_cap->data.replies.data = xrealloc(cur_cap->data.replies.data,
-			++cur_cap->data.replies.num * sizeof(u_char *));
-		cur_cap->data.replies.data[cur_cap->data.replies.num - 1] = (yyvsp[0].string);
+			sizeof(u_char *));
+		cur_cap->data.replies.data[0] = (yyvsp[0].string);
 	}
-#line 1575 "cfg_parse.c" /* yacc.c:1645  */
+#line 1586 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 335 "cfg_parse.y" /* yacc.c:1645  */
+#line 336 "cfg_parse.y" /* yacc.c:1652  */
     {
-		cur_cap->data.replies.data = xrealloc(cur_cap->data.replies.data,
-			++cur_cap->data.replies.num * sizeof(u_char *));
-		cur_cap->data.replies.data[cur_cap->data.replies.num - 1] = (yyvsp[0].string);
+		if (cur_cap->data.replies.num < 0xFF) {
+			cur_cap->data.replies.data = xrealloc(cur_cap->data.replies.data,
+				++cur_cap->data.replies.num * sizeof(u_char *));
+			cur_cap->data.replies.data[cur_cap->data.replies.num - 1] = (yyvsp[0].string);
+		} else {
+			o_log(LOG_CRIT, "[line %u] No more than 255 replies may be specified",
+				current_line);
+			free_cap_entries(cur_cap);
+			YYABORT;
+		}
 	}
-#line 1585 "cfg_parse.c" /* yacc.c:1645  */
+#line 1603 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 34:
-#line 343 "cfg_parse.y" /* yacc.c:1645  */
+#line 351 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap->caps = CAP_FORWARD;
 		cur_cap->action = ACTION_FORCE;
@@ -1613,20 +1631,20 @@ yyreduce:
 
 		free((yyvsp[-1].string)); free((yyvsp[0].string));
 	}
-#line 1617 "cfg_parse.c" /* yacc.c:1645  */
+#line 1635 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 35:
-#line 373 "cfg_parse.y" /* yacc.c:1645  */
+#line 381 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap->caps = (yyvsp[0].value);
 		cur_cap->action = ACTION_FORCE;
 	}
-#line 1626 "cfg_parse.c" /* yacc.c:1645  */
+#line 1644 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 38:
-#line 382 "cfg_parse.y" /* yacc.c:1645  */
+#line 390 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if ((yyvsp[-1].value) == ACTION_ALLOW)
 			cur_cap->caps |= (yyvsp[0].value);
@@ -1635,11 +1653,11 @@ yyreduce:
 
 		cur_cap->action = (yyvsp[-1].value);
 	}
-#line 1639 "cfg_parse.c" /* yacc.c:1645  */
+#line 1657 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 39:
-#line 391 "cfg_parse.y" /* yacc.c:1645  */
+#line 399 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if ((yyvsp[-1].value) == ACTION_ALLOW)
 			cur_cap->caps |= CAP_FORWARD;
@@ -1648,34 +1666,36 @@ yyreduce:
 
 		cur_cap->action = (yyvsp[-1].value);
 	}
-#line 1652 "cfg_parse.c" /* yacc.c:1645  */
+#line 1670 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 42:
-#line 408 "cfg_parse.y" /* yacc.c:1645  */
+#line 416 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap->caps = CAP_REPLY;
+		cur_cap->data.replies.num = 1;
 		cur_cap->data.replies.data = xrealloc(cur_cap->data.replies.data,
-			++cur_cap->data.replies.num * sizeof(u_char *));
-		cur_cap->data.replies.data[cur_cap->data.replies.num - 1] = (yyvsp[0].string);
+			sizeof(u_char *));
+		cur_cap->data.replies.data[0] = (yyvsp[0].string);
 	}
-#line 1663 "cfg_parse.c" /* yacc.c:1645  */
+#line 1682 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 43:
-#line 415 "cfg_parse.y" /* yacc.c:1645  */
+#line 424 "cfg_parse.y" /* yacc.c:1652  */
     {
-		if (cur_cap->data.replies.num < MAX_RANDOM_REPLIES) {
+		if (cur_cap->data.replies.num < MAX_RANDOM_REPLIES
+				&& cur_cap->data.replies.num < 0xFF) {
 			cur_cap->data.replies.data = xrealloc(cur_cap->data.replies.data,
 				++cur_cap->data.replies.num * sizeof(u_char *));
 			cur_cap->data.replies.data[cur_cap->data.replies.num - 1] = (yyvsp[0].string);
 		}
 	}
-#line 1675 "cfg_parse.c" /* yacc.c:1645  */
+#line 1695 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 44:
-#line 425 "cfg_parse.y" /* yacc.c:1645  */
+#line 435 "cfg_parse.y" /* yacc.c:1652  */
     {
 		cur_cap->caps = CAP_FORWARD;
 		cur_cap->data.forward.host = xmalloc(sizeof(struct sockaddr_storage));
@@ -1702,11 +1722,11 @@ yyreduce:
 
 		free((yyvsp[-1].string)); free((yyvsp[0].string));
 	}
-#line 1706 "cfg_parse.c" /* yacc.c:1645  */
+#line 1726 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
   case 45:
-#line 454 "cfg_parse.y" /* yacc.c:1645  */
+#line 464 "cfg_parse.y" /* yacc.c:1652  */
     {
 		if ((yyvsp[0].value) == CAP_SPOOF || (yyvsp[0].value) == CAP_SPOOF_ALL || (yyvsp[0].value) == CAP_SPOOF_PRIVPORT)
 		{
@@ -1716,11 +1736,11 @@ yyreduce:
 
 		cur_cap->caps = (yyvsp[0].value);
 	}
-#line 1720 "cfg_parse.c" /* yacc.c:1645  */
+#line 1740 "cfg_parse.c" /* yacc.c:1652  */
     break;
 
 
-#line 1724 "cfg_parse.c" /* yacc.c:1645  */
+#line 1744 "cfg_parse.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1834,12 +1854,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1901,6 +1919,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1908,6 +1927,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1918,6 +1938,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1947,7 +1971,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 469 "cfg_parse.y" /* yacc.c:1903  */
+#line 479 "cfg_parse.y" /* yacc.c:1918  */
 
 
 /*
@@ -1976,7 +2000,7 @@ int read_config(const char *path) {
 			}
 		}
 
-		o_log(LOG_CRIT, "Error opening config file: %s: %s",
+		o_log(LOG_CRIT, "Error opening configuration file: %s: %s",
 			path, strerror(errno));
 		return -1;
 	}
@@ -2003,14 +2027,20 @@ int read_config(const char *path) {
 }
 
 /*
-** Open the user's ~/.oidentd.conf file for reading
-** by the parser.
+** Open the user's configuration file for reading by the parser.
 */
 
 static FILE *open_user_config(const struct passwd *pw) {
-	FILE *fp;
+	FILE *fp = NULL;
+
+#if XDGBDIR_SUPPORT
+	if (!fp)
+		fp = safe_open(pw, USER_CONF_XDG);
+#endif
+
+	if (!fp)
+		fp = safe_open(pw, USER_CONF);
 
-	fp = safe_open(pw, USER_CONF);
 	if (!fp)
 		return NULL;
 
@@ -2022,7 +2052,7 @@ static FILE *open_user_config(const struct passwd *pw) {
 }
 
 /*
-** Read in a user's $HOME/.oidentd.conf file.
+** Read in a user's configuration file.
 */
 
 list_t *user_db_get_pref_list(const struct passwd *pw) {
@@ -2048,7 +2078,6 @@ list_t *user_db_get_pref_list(const struct passwd *pw) {
 }
 
 static void yyerror(const char *err) {
-
 	if (parser_mode == PARSE_USER)
 		free_cap_entries(cur_cap);
 	else
