@@ -1,5 +1,5 @@
 /*
-** oidentd_inet_util.c - oidentd network utility functions.
+** inet_util.c - oidentd network utility functions.
 ** Copyright (c) 2001-2006 Ryan McCabe <ryan@numb.org>
 ** Copyright (c) 2018-2019 Janik Rabe  <oidentd@janikrabe.com>
 **
@@ -240,7 +240,7 @@ ssize_t sock_write(int sock, void *buf, ssize_t len) {
 	while (len > 0) {
 		ssize_t n;
 
-		n = write(sock, buf, len);
+		n = write(sock, buf, (size_t) len);
 		if (n == -1) {
 			if (errno == EINTR)
 				continue;
@@ -315,7 +315,7 @@ int get_port(const char *name, in_port_t *port) {
 		if (!VALID_PORT(temp_port))
 			return -1;
 
-		*port = temp_port;
+		*port = (in_port_t) temp_port;
 	}
 
 	return 0;
@@ -391,10 +391,7 @@ inline void get_ip(	struct sockaddr_storage *ss,
 inline bool sin4_equal(	struct sockaddr_storage *ss1,
 						struct sockaddr_storage *ss2)
 {
-	if (SIN4(ss1)->sin_addr.s_addr == SIN4(ss2)->sin_addr.s_addr)
-		return true;
-
-	return false;
+	return (SIN4(ss1)->sin_addr.s_addr == SIN4(ss2)->sin_addr.s_addr);
 }
 
 /*
@@ -424,7 +421,7 @@ inline bool sin6_equal(	struct sockaddr_storage *ss1,
 void sin_setv6(struct in6_addr *sin6, struct sockaddr_storage *ss) {
 	memset(ss, 0, sizeof(struct sockaddr_storage));
 	ss->ss_family = AF_INET6;
-	memcpy(&SIN6(ss)->sin6_addr, sin6, sizeof(struct sockaddr_in6));
+	memcpy(&SIN6(ss)->sin6_addr, sin6, sizeof(struct in6_addr));
 }
 
 #endif
