@@ -56,6 +56,8 @@
 #include "masq.h"
 #include "options.h"
 
+#define PF_DEVICE "/dev/pf"
+
 extern struct sockaddr_storage proxy;
 
 /*
@@ -142,9 +144,9 @@ int masq(	int sock,
 	if (faddr->ss_family != AF_INET || laddr->ss_family != AF_INET)
 		return -1;
 
-	pfdev = open("/dev/pf", O_RDWR);
+	pfdev = open(PF_DEVICE, O_RDWR);
 	if (pfdev == -1) {
-		debug("open: %s", strerror(errno));
+		debug("open: %s: %s", PF_DEVICE, strerror(errno));
 		return -1;
 	}
 
@@ -201,7 +203,7 @@ int masq(	int sock,
 
 		get_ip(faddr, ipbuf, sizeof(ipbuf));
 
-		o_log(NORMAL,
+		o_log(LOG_INFO,
 				"[%s] (NAT) Successful lookup: %d , %d : %s",
 				ipbuf, lport, fport, user);
 
@@ -269,9 +271,19 @@ uid_t get_user6(	in_port_t lport,
 #endif
 
 /*
-** Stub k_open() function.
+** Open the kernel memory device.
+** Return 0 on success, or -1 with errno set.
+**
+** No kmem access required; nothing to do.
 */
 
 int k_open(void) {
+#ifdef HAVE_UNVEIL
+	if (unveil("/", "r")) {
+		debug("unveil: %s", strerror(errno));
+		return -1;
+	}
+#endif
+
 	return 0;
 }
